@@ -1,6 +1,6 @@
 #*****************************************
 #
-# (C) Copyright IBM Corp. 2017
+# (C) Copyright IBM Corp. 2017, 2020
 # Author: Ernesto Arandia & Bradley J Eck
 #
 #*****************************************
@@ -10,7 +10,6 @@
 context("Get option")
 
 test_that("no crash calling on closed toolkit",{
-			expect_false( getOpenflag() )
 			expect_error( x <- ENgetoption(0) ) 
 		})
 
@@ -35,6 +34,12 @@ test_that("works for numeric input",{
 			expect_equal( 40, opt)
 			ENclose()	
 		})
+test_that("returns a numeric ok",{
+			ENopen("Net1.inp", "Net1.rpt")
+			opt <- ENgetoption(1) 
+			expect_equal( 0.001, opt)
+			ENclose()	
+		})
 
 test_that("gives error on multiple input",{
 			ENopen("Net1.inp", "Net1.rpt")
@@ -54,7 +59,6 @@ test_that("returns error 251",{
 context("Set option")
 
 test_that("no crash calling on closed toolkit",{
-			expect_false( getOpenflag() )
 			expect_error( x <- ENsetoption(0,33) ) 
 		})
 
@@ -105,19 +109,3 @@ test_that("returns NULL invisibly on success",{
 		})
 
 
-context("get flow units")
-test_that("no crash calling on closed toolkit",{
-			expect_error(	x <- ENgetflowunits() )
-		})
-test_that("works",{
-			
-			
-			ENopen("Net1.inp","Net1.rpt")  
-			x <- ENgetflowunits()
-			ENclose()
-			
-			y <- 1 
-			names(y) <- "EN_GPM"
-			expect_equal(x,y )
-		})
-
